@@ -16,7 +16,9 @@ try:
     elif sys.platform == 'linux':        
         lib_agora_rtc_path =os.path.join(lib_path, 'libagora_rtc_sdk.so')
         ctypes.CDLL(os.path.join(lib_path, 'libagora-fdkaac.so'))
-        ctypes.CDLL(os.path.join(lib_path, 'libaosl.so'))
+        ctypes.CDLL(os.path.join(lib_path, 'libagora-core.so'))
+        ctypes.CDLL(os.path.join(lib_path, 'libagora-soundtouch.so'))
+        ctypes.CDLL(os.path.join(lib_path, 'libagora_uap_aed.so'))
         agora_lib = ctypes.CDLL(lib_agora_rtc_path)
 except OSError as e:
     print(f"Error loading the library: {e}")
